==> webindex-2.0.4.tar.gz: webindex-2.0.4/Exiftimestamps.sh <==
#!/bin/sh
# @(#) $Id: Exiftimestamps.sh 270 2015-07-05 02:02:49Z leres $ (XSE)
#
# Exiftimestamps - set jpg timestamps using exiftags and touch
#

prog="`basename $0`"
usage="usage: ${prog} [-nv] file ..."

args=`getopt nv $*`

if [ $? -ne 0 ]; then
	echo "${usage}" 1>&2
	exit 1
fi

set -- ${args}

dryrun=0
verbose=0

for a do
	case "${a}" in

	-n)
		dryrun=1
		shift
		;;

	-v)
		verbose=1
		shift
		;;

	--)
		shift
		break
		;;
	esac
done

if [ $# -lt 1 ]; then
	echo "${usage}" 1>&2
	exit 1
fi

# We need the sysv version under Solaris
touch="/usr/bin/touch"
if [ ! -x ${touch} ]; then
	touch="touch"
fi

# Execute (or echo if -n)
execute() {
	cmd="$*"
	if [ ${dryrun} -ne 0 -o ${verbose} -ne 0 ]; then
		echo "+ ${cmd}"
	fi
	if [ ${dryrun} -eq 0 ]; then
		eval "${cmd}"
		return $?
	fi
	return 0
}

gettimestamp()
{
	awk '
	/^Image Created:/ {
		stime = $3 ":" $4
		n = split(stime, a, ":")
		if (n == 6) {
			print a[1] a[2] a[3] a[4] a[5] "." a[6]
			exit
		}
	}
	'
}

# Make sure we have everything we need
for f in exiftags; do
	which ${f} > /dev/null 2>&1
	if [ $? -ne 0 ]; then
		echo "${prog}: Can't find ${f}" 1>&2
		exit 1
	fi
done

while [ $# -gt 0 ]; do
	f="$1"
	shift

	case "`echo ${f} | tr A-Z a-z`" in

	*.jpg)
		# Ok
		;;

	*.jpg-)
		# Ok
		;;

	*)
		echo "${prog}: ${f} unexpected file extension (skipping)"
		status=1
		continue
		;;
	esac

	if [ ! -r ${f} ]; then
		echo "${prog}: Can't find ${f}"
		status=1
		continue
	fi

	#ts="`exiftags ${f} | sed -n -e '^Image Created: \('`"
	ts="`exiftags ${f} | gettimestamp`"
	if [ -z "${ts}" ]; then
		echo "${prog}: ${f}: Didn't find a timestamp"
		continue
	fi

	execute "touch -t ${ts} ${f}"
done

exit ${status}

==> webindex-3.3.tar.gz: webindex-3.3/Exiftimestamps.sh <==
#!/bin/sh
# @(#) $Id: Exiftimestamps.sh 297 2019-03-02 22:29:03Z leres $ (XSE)
#
# Exiftimestamps - set jpg timestamps using exiftags and touch
#

prog="`basename $0`"

usage()
{
	echo "usage: ${prog} [-dnv] file ..." 1>&2
	exit 1
}

args=`getopt dnv $*`

if [ $? -ne 0 ]; then
	usage
fi

set -- ${args}

dryrun=0
verbose=0
debug=0

for a do
	case "${a}" in

	-d)
		debug=1
		shift
		;;

	-n)
		dryrun=1
		shift
		;;

	-v)
		verbose=1
		shift
		;;

	--)
		shift
		break
		;;
	esac
done

if [ $# -lt 1 ]; then
	usage
fi

# We need the sysv version under Solaris
touch="/usr/bin/touch"
if [ ! -x ${touch} ]; then
	touch="touch"
fi

# Execute (or echo if -n)
execute() {
	cmd="$*"
	if [ ${dryrun} -ne 0 -o ${verbose} -ne 0 ]; then
		echo "+ ${cmd}"
	fi
	if [ ${dryrun} -eq 0 ]; then
		eval "${cmd}"
		return $?
	fi
	return 0
}

# Make sure we have everything we need
for f in exiftool; do
	which ${f} > /dev/null 2>&1
	if [ $? -ne 0 ]; then
		echo "${prog}: Can't find ${f}" 1>&2
		exit 1
	fi
done

tag=

while [ $# -gt 0 ]; do
	f="$1"
	shift

	case "`echo ${f} | tr A-Z a-z`" in

	*.jpg)
		tag=CreateDate
		;;

	*.jpg-)
		tag=CreateDate
		;;

	*.png)
		tag=DateCreated
		;;

	*.png-)
		tag=DateCreated
		;;

	*)
		echo "${prog}: ${f} unsupported file extension (skipping)" 1>&2
		status=1
		continue
		;;
	esac

	if [ ! -r ${f} ]; then
		echo "${prog}: Can't find ${f}"
		status=1
		continue
	fi

	cmd="exiftool -d %Y%m%d%H%M.%S -${tag} ${f}"
	if [ ${debug} -ne 0 ]; then
		echo "+ ${cmd}" 1>&2
	fi
	ts="`${cmd} | awk '{ print $NF }'`"
	if [ -z "${ts}" ]; then
		echo "${prog}: ${f}: Didn't find a timestamp" 1>&2
		continue
	fi

	execute "touch -t ${ts} ${f}"
done

exit ${status}
